#pragma once
#include "def.h"
#include "physics.h"
#include "ship.h"

#define PILOT_PLAYER    1 // Pilot is a player.

// =========================================================
// AI:
// Ai is based on an action list which contains the current
// action (FIFO). Actions will run the appropriate Lua code.
// =========================================================
typedef enum { ACT_ATTACK, ACT_TRAVEL, ACT_BRAKE } action_type;

// Actions.
struct Action {
  struct Action* next;
  action_type type;
  void* target;
};
typedef struct Action Action;

// Primary pilot structure.
struct Pilot {
  unsigned int id; // Pilots id.
  char* name;     // Pilot's name (if unique).

  // Object characteristics.
  Ship* ship;     // Pilots ship.
  Solid* solid;   // Associated solid (physics).

  // Current health.
  FP armor, shield, energy;

  void (*update)(struct Pilot*, const FP); // Update the pilot.

  unsigned int properties; // Used for AI etc.

  // AI.
  void (*think)(struct Pilot*); // Ai thinking for the pilot.
  Action* action; // Current action.
};
typedef struct Pilot Pilot;

extern Pilot* player; // The player.
Pilot* get_pilot(unsigned int id);

// Creation.
void pilot_init(Pilot* dest, Ship* ship, char* name,
      const Vec2* vel, const Vec2* pos, const int flags);

unsigned int pilot_create(Ship* ship, char* name, const Vec2* vel,
      const Vec2* pos, const int flags);

// Cleanup.
void pilots_free(void);

// Update.
void pilots_update(FP dt);

